@@ -77,7 +77,7 @@ try:
 except ImportError:
     pass
 
-__version__ = "5.0.0"
+__version__ = "5.0.1"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_Logger.git"
 
 # pylint:disable=undefined-all-variable
@@ -141,9 +141,9 @@ be retrieved from it:
 - ``args`` - The additional positional arguments provided
 """
 
-_logRecordFactory = lambda name, level, msg, args: LogRecord(
-    name, level, _level_for(level), msg, time.monotonic(), args
-)
+
+def _logRecordFactory(name, level, msg, args):
+    return LogRecord(name, level, _level_for(level), msg, time.monotonic(), args)
 
 
 class Handler:
